#########################################
### This file executes the empirical work
### in Chapter 10: Method of Moments
#########################################
### Uses data file cps09mar.txt
#########################################

dat <- read.table("cps09mar.txt")
experience <- dat[,1]-dat[,4]-6
mwm <- (dat[,11]==1)&(dat[,12]<=2)&(dat[,2]==0)&(experience==20)
dat1 <- dat[mwm,]
wage <- as.matrix(dat1[,5]/(dat1[,6]*dat1[,7]))
lwage <- log(wage)
education <- as.matrix(dat1[,4])
n <- length(wage)

mwage <- mean(wage)
mlwage <- mean(lwage)
meducation <- mean(education)
vwage <- var(wage)
vlwage <- var(lwage)
veducation <- var(education)
x <- cbind(wage,education)
c <- cov(x)
swage <- sd(wage)
slwage <- sd(lwage)
seducation <- sd(education)

sewage <- swage/sqrt(n)
seeducation <- seducation/sqrt(n)

wwage <- wage/100
wagem <- (wwage%*%matrix(1,1,4))^(matrix(1,n,1)%*%(1:4))
mwagem <- colMeans(wagem)
semwagem <- sqrt(colMeans((wagem - matrix(1,n,1)%*%mwagem)^2)/(n-1))

cwage <- wwage - mean(wwage)
cwagem <- (cwage%*%matrix(1,1,5))^(matrix(1,n,1)%*%(1:5))
cmwagem <- colMeans(cwagem)
cmwagem[1] <- mwagem[1]
v <- cov(cwagem)

secmwage <- matrix(0,1,4)
secmwage[1] <- var(wwage)
secmwage[2] <- var(cwage^2)
for (m in 3:4) {
 secmwage[m] <- v[m,m] + ((m*cmwagem[m-1])^2)*var(wwage) -2*m*cmwagem[m-1]*cmwagem[m+1]
}
cmwagem <- cmwagem[1:4]
secmwage <- sqrt(secmwage/n)

gmean <- exp(mlwage)
segmean <- gmean*slwage/sqrt(n)

ratio <- mwage/meducation
vr <- (swage/meducation)^2 - 2*c[2,1]*mwage/(meducation^3) + ((seducation*mwage)^2)/(meducation^4)
ser <- sqrt(vr/n)

sdwage2 <- sd((wage-mwage)^2)
sevwage <- sdwage2/sqrt(n)

# Gamma Model
alpha <- (mwage^2)/vwage
beta <- vwage/mwage
H <- matrix(0,2,2)
H[1,1] <- -1/beta^2
H[2,1] <- 2*(1+alpha)/beta
H[1,2] <- 1/mwage
H[2,2] <- -(2+1/alpha)
V <- matrix(0,2,2)
V[1,1] <- var(wage^2)
V[2,1] <- V[1,2] <- cov(wage,wage^2)
V[2,2] <- var(wage)
Vg <- t(H)%*%V%*%H/n

# Lognormal
theta <- mlwage
v2 <- vlwage

# student t
mu4 <- mean((wage-mwage)^4)
v4 <- vwage^2
thetat <- mwage
v2t <- mu4*vwage/(2*mu4-3*v4)
r <- (4*mu4-6*v4)/(mu4-3*v4)

cat("\n")
cat("Sample size, mean wage, mean education \n")
print(c(n,mwage,meducation))
cat("\n")
cat("Variance matrix: wage, education \n")
print(c)
cat("\n")
cat("s.e. of mean estimator: wage, education \n")
print(c(sewage,seeducation))
cat("\n")
cat("moments, 1-4, with standard errors \n")
print(mwagem)
print(semwagem)
cat("\n")

cat("centered moments, 1-4, with standard errors \n")
print(cmwagem)
print(secmwage)
cat("\n")

cat("Geometric mean, sd, & standard error \n")
print(c(gmean,slwage,segmean))
cat("\n")
cat("ratio of means, variance, & standard error \n")
print(c(ratio,vr,ser))
cat("\n")
cat("variance: variance of X^2, s.e. \n")
print(c(sdwage2,sevwage))
cat("\n")

cat("Gamma Model: alpha, beta \n")
print(c(alpha,beta))
print(sqrt(diag(Vg)))
cat("\n")

cat("Lognormal Model: theta, v2 \n")
print(c(theta,v2))
cat("\n")

cat("student t Model: theta, v2, r \n")
print(c(thetat,v2t,r))
cat("\n")


