#####################################
### This file generates Figures 10.2-10.5
### Likelihood Functions
#####################################


#####################################
### Normal
#####################################

x <- seq(-1,3,by=0.01)
xbar <- 1
f <- -((x-xbar)^2)/2-log(2*pi)/2
fbar <- max(f)

pdf("hansen10-2.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",ylim=c(-3,-.68),xlab=expression(mu),yaxt="n",bty="n",cex.lab=.8,cex.axis=.75)
points(xbar,fbar,pch=19,col="black",cex=.8)
text(xbar,-.78,expression(hat(mu)),cex=.8)
text(2.5,-1.6,expression(l[n](mu)),cex=.8)
dev.off()

postscript("hansen10-2.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",ylim=c(-3,-.68),xlab=expression(mu),yaxt="n",bty="n",cex.lab=.8,cex.axis=.75)
points(xbar,fbar,pch=19,col="black",cex=.8)
text(xbar,-.78,expression(hat(mu)),cex=.8)
text(2.5,-1.6,expression(l[n](mu)),cex=.8)
dev.off()

#####################################
### Normal Variance
#####################################

x <- seq(.01,3,.01)
f <- -log(2*pi)/2 - log(x)/2 - (1/2)/x
xbar <- 1
fbar <- max(f)

pdf("hansen10-3.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",ylim=c(-1.7,-1.38),xlim=c(.4,3),xlab=expression(sigma^2),xaxt="n",yaxt="n",bty="n",cex.lab=.8,cex.axis=.75)
points(xbar,fbar,pch=19,col="black",cex=.8)
axis(side=1,seq(0,3,.5),cex.axis=.75)
text(xbar,-1.395,expression(hat(sigma)^2),cex=.8)
text(2.2,-1.5,expression(l[n](sigma^2)),cex=.8)
dev.off()

postscript("hansen10-3.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",ylim=c(-1.7,-1.38),xlim=c(.4,3),xlab=expression(sigma^2),xaxt="n",yaxt="n",bty="n",cex.lab=.8,cex.axis=.75)
points(xbar,fbar,pch=19,col="black",cex=.8)
axis(side=1,seq(0,3,.5),cex.axis=.75)
text(xbar,-1.395,expression(hat(sigma)^2),cex=.8)
text(2.2,-1.5,expression(l[n](sigma^2)),cex=.8)
dev.off()

#####################################
### Uniform
#####################################

x <- seq(.9,2,by=0.01)
g <- 1/x
xbar <- min(x)
gbar <- max(g)

pdf("hansen10-4.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,g,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab=expression(theta),ylim=c(.5,1.25),xlim=c(0,2),yaxt="n",bty="n",cex.lab=.8,cex.axis=.75)
lines(c(0,xbar),c(gbar,gbar),lty=2)
lines(c(xbar,xbar),c(gbar,.5))
points(xbar,gbar,pch=4,col="black",cex=1.3)
points(.2,gbar,pch=4,col="black",cex=1.3)
points(.4,gbar,pch=4,col="black",cex=1.3)
points(.5,gbar,pch=4,col="black",cex=1.3)
points(.8,gbar,pch=4,col="black",cex=1.3)
points(xbar,gbar,pch=19,col="black",cex=.8)
text(1.3,0.85,expression(l[n](theta)),cex=.8)
text(xbar,1.17,expression(hat(theta)),cex=.9)
dev.off()

postscript("hansen10-4.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,g,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab=expression(theta),ylim=c(.5,1.25),xlim=c(0,2),yaxt="n",bty="n",cex.lab=.8,cex.axis=.75)
lines(c(0,xbar),c(gbar,gbar),lty=2)
lines(c(xbar,xbar),c(gbar,.5))
points(xbar,gbar,pch=4,col="black",cex=1.3)
points(.2,gbar,pch=4,col="black",cex=1.3)
points(.4,gbar,pch=4,col="black",cex=1.3)
points(.5,gbar,pch=4,col="black",cex=1.3)
points(.8,gbar,pch=4,col="black",cex=1.3)
points(xbar,gbar,pch=19,col="black",cex=.8)
text(1.3,0.85,expression(l[n](theta)),cex=.8)
text(xbar,1.17,expression(hat(theta)),cex=.9)
dev.off()

#####################################
### Mixture
#####################################

x <- seq(0,1,by=0.01)
m1 <- 1
m2 <- -1
x1 <- -1
x2 <- .5
x3 <- 1.5
f <- log(dnorm(x1-m1)*x+dnorm(x1-m2)*(1-x)) + log(dnorm(x2-m1)*x+dnorm(x2-m2)*(1-x)) + log(dnorm(x3-m1)*x+dnorm(x3-m2)*(1-x))
fm <- max(f)
p <- x[which.max(f)]

pdf("hansen10-5.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="p",xlim=c(0,1.01),ylim=c(-6,-4.3),xaxt="n",yaxt="n",bty="n",cex.lab=.8)
axis(side=1,seq(0,1,.2),cex.axis=.75)
lines(c(1,1),c(min(f),f[101]))
points(p,fm,pch=19,col="black",cex=.8)
text(p,-4.38,expression(hat(p)),cex=.8)
text(.22,-5,expression(l[n](p)),cex=.8)
dev.off()

postscript("hansen10-5.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="p",xlim=c(0,1.01),ylim=c(-6,-4.3),xaxt="n",yaxt="n",bty="n",cex.lab=.8)
axis(side=1,seq(0,1,.2),cex.axis=.75)
lines(c(1,1),c(min(f),f[101]))
points(p,fm,pch=19,col="black",cex=.8)
text(p,-4.38,expression(hat(p)),cex=.8)
text(.22,-5,expression(l[n](p)),cex=.8)
dev.off()
