#####################################
### This file generates Figure 11.1
### Best Unbiased Estimation
#####################################
### Uses package spatstat
#########################################

library(spatstat)

x <- seq(-1,1,.01)
f1 <- (1 - (x^2))*3/4
f2 <- f1*(1+x)
leg1 <- expression(f(x))
leg2 <- expression(f[mu](x))

wd <- 1.4

pdf("hansen11-1a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f1,type="l",lty=1,xaxs="i",yaxs="i",xaxt="n",xlim=c(-1,1),ylim=c(-0.075,1),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
abline(h=0,lwd=wd)
lines(x,f2,lwd=wd)
arrows(0,.75,0,0,angle=20,length=.2)
arrows(.2,108/125,.2,0,angle=20,length=.2)
text(0,-.05,expression(mu[0]))
text(.2,-.05,expression(mu))
text(-.65,.6,leg1)
text(.85,.7,leg2)
dev.off()

postscript("hansen11-1a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f1,type="l",lty=1,xaxs="i",yaxs="i",xaxt="n",xlim=c(-1,1),ylim=c(-0.075,1),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
abline(h=0,lwd=wd)
lines(x,f2,lwd=wd)
arrows(0,.75,0,0,angle=20,length=.2)
arrows(.2,108/125,.2,0,angle=20,length=.2)
text(0,-.05,expression(mu[0]))
text(.2,-.05,expression(mu))
text(-.65,.6,leg1)
text(.85,.7,leg2)
dev.off()

x <- seq(-1,1,.01)
y <- (abs(x)^(1/2))*((x>0) - (x<0))

pdf("hansen11-1b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot.new()
plot.window(c(-4,4),c(-4,4))
W <- ellipse(a=3,b=3.5,centre=c(0,0),phi=0,npoly=1024)
plot(W,add=TRUE,lwd=wd)
lines(x,y,lwd=wd)
points(0,0,pch=19,col="black")
text(-2.2,3.2,expression(bold(F[2])))
text(0.5,0,expression(italic(F[0])))
text(1.4,1,expression(italic(F[mu])))
dev.off()

postscript("hansen11-1b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot.new()
plot.window(c(-4,4),c(-4,4))
W <- ellipse(a=3,b=3.5,centre=c(0,0),phi=0,npoly=1024)
plot(W,add=TRUE,lwd=wd)
lines(x,y,lwd=wd)
points(0,0,pch=19,col="black")
text(-2.2,3.2,expression(bold(F[2])))
text(0.5,0,expression(italic(F[0])))
text(1.4,1,expression(italic(F[mu])))
dev.off()