#####################################
### This file generates Figure 11.2
### Wage Densities
#####################################
### Uses data file cps09mar.txt
#########################################

dat <- read.table("cps09mar.txt")
experience <- dat[,1]-dat[,4]-6
mwm <- (dat[,11]==1)&(dat[,12]<=2)&(dat[,2]==0)&(experience==20)
dat1 <- dat[mwm,]
wage <- as.matrix(dat1[,5]/(dat1[,6]*dat1[,7]))

x <- as.vector(seq(0.1,100,.1))

# Normal
m <- as.vector(mean(wage))
s <- as.vector(sd(wage))
f1 <- dnorm(x,m,s)

# Gamma
v <- as.vector(var(wage))
alpha <- (m^2)/v
beta <- v/m
f2 <- (x^(alpha-1))*exp(-x/beta)/gamma(alpha)/(beta^alpha)

# Log Normal
lwage <- log(wage)
m2 <- as.vector(mean(lwage))
v2 <- as.vector(var(lwage))
f3 <- exp(-((log(x)-m2)^2)/2/v2)/x/sqrt(2*pi*v2)

# Student t
mu4 <- as.vector(mean((wage-m)^4))
v4 <- v^2
v2t <- mu4*v/(2*mu4-3*v4)
r <- (4*mu4-6*v4)/(mu4-3*v4)
r1 <- (r+1)/2
f4 <- ((((x-m)^2)/r/v2t+1)^(-r1))*gamma(r1)/sqrt(r*pi*v2t)/gamma(r/2)


leg1 <- "Normal"
leg2 <- "Gamma"
leg3 <- "Log Normal"
leg4 <- "Student t"

pdf("hansen11-2.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f1,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",xlim=c(-1,100),ylim=c(0,.031),xaxt="n",yaxt="n",bty="n")
lines(x,f2,lty=5)
lines(x,f3,lty=2)
lines(x,f4,lty=6)
legend("topright",legend=c(leg1,leg2,leg3,leg4),lty=c(1,5,2,6),y.intersp=1.3,cex=.75,bty="n")
axis(side=1,seq(0,100,10),cex.axis=.75)
abline(v=0)
dev.off()

postscript("hansen11-2.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f1,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",xlim=c(-1,100),ylim=c(0,.031),xaxt="n",yaxt="n",bty="n")
lines(x,f2,lty=5)
lines(x,f3,lty=2)
lines(x,f4,lty=6)
legend("topright",legend=c(leg1,leg2,leg3,leg4),lty=c(1,5,2,6),y.intersp=1.3,cex=.75,bty="n")
axis(side=1,seq(0,100,10),cex.axis=.75)
abline(v=0)
dev.off()

