#####################################
### This file generates Figure 12.1
### Root Finding
#####################################

fx <- function(x) {
  y <- exp(x)/sqrt(x) - exp(2)/sqrt(2)
  return(y)
}
dx <- function(x) {
  d <- exp(x)/sqrt(x) - exp(x)/(2*(x^1.5))
  return(d)
}

x <- seq(1,4,by=0.05)
f <- fx(x)
x0 <- x[which.min(abs(f))]


### Newton Search

R <- 5
xi <- matrix(0,R,1)
fi <- matrix(0,R,1)

wd <- 1.4

pdf("hansen12-1a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n",ylim=c(-3,23),xlim=c(1,4.04),lwd=wd)
abline(h=0,lty=3,lwd=wd)
points(x0,0,pch=19,col="black",cex=.8)
points(x0,0,pch=1,col="black",cex=1.5)
axis(side=1,seq(0,5,.5),lwd=wd)
axis(side=2,seq(-5,25,5),lwd=wd)
xi[1] <- xx <- 4
fi[1] <- ff <- fx(xx)
points(xx,ff,pch=19,col="black")
text(xx-.1,ff+.5,"1")
for (i in 2:R){
  d <- dx(xx)
  xi[i] <- xx <- xx - ff/d
  fi[i] <- ff <- fx(xx)
  x1 <- xi[i-1] - (fi[i-1]-ff)/d
  if (i<5)   points(xx,ff,pch=19,col="black",cex=.8)
  if (i<5)   text(xx,ff+1.5,i)
  if (i==5)   text(xx-.05,ff+1.5,i)
  arrows(xi[i-1],fi[i-1],x1,ff,angle=20,length=.1)
}
dev.off()

postscript("hansen12-1a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n",ylim=c(-3,23),xlim=c(1,4.04),lwd=wd)
abline(h=0,lty=3,lwd=wd)
points(x0,0,pch=19,col="black",cex=.8)
points(x0,0,pch=1,col="black",cex=1.5)
axis(side=1,seq(0,5,.5),lwd=wd)
axis(side=2,seq(-5,25,5),lwd=wd)
xi[1] <- xx <- 4
fi[1] <- ff <- fx(xx)
points(xx,ff,pch=19,col="black")
text(xx-.1,ff+.5,"1")
for (i in 2:R){
  d <- dx(xx)
  xi[i] <- xx <- xx - ff/d
  fi[i] <- ff <- fx(xx)
  x1 <- xi[i-1] - (fi[i-1]-ff)/d
  if (i<5)   points(xx,ff,pch=19,col="black",cex=.8)
  if (i<5)   text(xx,ff+1.5,i)
  if (i==5)   text(xx-.05,ff+1.5,i)
  arrows(xi[i-1],fi[i-1],x1,ff,angle=20,length=.1)
}
dev.off()

cat("Newton Search \n")
print(cbind(xi,fi))

### Bisection Search

R <- 10

pdf("hansen12-1b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n",ylim=c(-3,23),xlim=c(.96,4.04),lwd=wd)
axis(side=1,seq(0,5,.5),lwd=wd)
axis(side=2,seq(-5,25,5),lwd=wd)
abline(h=0,lty=3)
a <- min(x)
b <- max(x)
fa <- fx(a)
fb <- fx(b)
points(a,fa,pch=19,col="black",cex=.8)
text(a+.05,fa+1,"a")
points(b,fb,pch=19,col="black",cex=.8)
text(b-.1,fb,"b")
c <- (a+b)/2
fc <- fx(c)
lines(c(a,b),c(fa,fb),lty=2,lwd=wd)
ff <- (fa+fb)/2
points(c,ff,pch=19,col="black",cex=.8)
arrows(c,ff,c,fc,angle=20,length=.1)
text(c,ff+1,"c")
lines(c(a,c),c(fa,fc),lty=2,lwd=wd)
d <- (a+c)/2
fd <- fx(d)
points(d,(fa+fc)/2,pch=19,col="black",cex=.8)
lines(c(d,d),c((fa+fc)/2,fd),lty=2,lwd=wd)
lines(c(d,c),c(fd,fc),lty=2,lwd=wd)
text(c,fc-1.5,"f(c)")
text(d,(fa+fc)/2+1,expression(d))
text(d,fd-1,expression(f(d)))
points(x0,0,pch=19,col="black",cex=.8)
points(x0,0,pch=1,col="black",cex=1.5)
cat("Bisection Search \n")
print(cbind(a,b))
for (i in 3:R){
  c <- (a+b)/2
  fc <- fx(c)
  if (fc*fa > 0) {
    a <- c
    fa <- fc
  } else {
    b <- c
    fb <- fc
  }
  if (i<7) points(c,fc,pch=19,col="black",cex=.8)
  if (i==5) text(c,fc-1.5,expression(e))
  print(cbind(a,b))
}
dev.off()

postscript("hansen12-1b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n",ylim=c(-3,23),xlim=c(.96,4.04),lwd=wd)
axis(side=1,seq(0,5,.5),lwd=wd)
axis(side=2,seq(-5,25,5),lwd=wd)
abline(h=0,lty=3)
a <- min(x)
b <- max(x)
fa <- fx(a)
fb <- fx(b)
points(a,fa,pch=19,col="black",cex=.8)
text(a+.05,fa+1,"a")
points(b,fb,pch=19,col="black",cex=.8)
text(b-.1,fb,"b")
c <- (a+b)/2
fc <- fx(c)
lines(c(a,b),c(fa,fb),lty=2,lwd=wd)
ff <- (fa+fb)/2
points(c,ff,pch=19,col="black",cex=.8)
arrows(c,ff,c,fc,angle=20,length=.1)
text(c,ff+1,"c")
lines(c(a,c),c(fa,fc),lty=2,lwd=wd)
d <- (a+c)/2
fd <- fx(d)
points(d,(fa+fc)/2,pch=19,col="black",cex=.8)
lines(c(d,d),c((fa+fc)/2,fd),lty=2,lwd=wd)
lines(c(d,c),c(fd,fc),lty=2,lwd=wd)
text(c,fc-1.5,"f(c)")
text(d,(fa+fc)/2+1,expression(d))
text(d,fd-1,expression(f(d)))
points(x0,0,pch=19,col="black",cex=.8)
points(x0,0,pch=1,col="black",cex=1.5)
cat("Bisection Search \n")
print(cbind(a,b))
for (i in 3:R){
  c <- (a+b)/2
  fc <- fx(c)
  if (fc*fa > 0) {
    a <- c
    fa <- fc
  } else {
    b <- c
    fb <- fc
  }
  if (i<7) points(c,fc,pch=19,col="black",cex=.8)
  if (i==5) text(c,fc-1.5,expression(e))
  print(cbind(a,b))
}
dev.off()
