#####################################
### This file generates Figure 12.2
### Min in one dimension
#####################################


fx <- function(x) {
  y <- -log(x)+x/2
  return(y)
}
dx <- function(x) {
  d <- -1/x+1/2
  return(d)
}
hx <- function(x) {
  d <- 1/x^2
  return(d)
}

x <- seq(.1,4,by=0.05)
f <- fx(x)
x0 <- x[which.min(abs(f))]
f0 = fx(x0)

## Newton Search

wd <- 1.4

pdf("hansen12-2a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",ylim=c(0,2.5),xlim=c(0,4),xaxt="n",bty="n",lwd=wd)
axis(side=1,seq(0,4,1),lwd=wd)
axis(side=2,lwd=wd)
points(x0,f0,pch=1,col="black",cex=1.4)
R <- 8
xi <- matrix(0,R,1)
fi <- matrix(0,R,1)
xi[1] <- xx <- .1
fi[1] <- ff <- fx(xx)
points(xx,ff,pch=19,col="black",cex=.8)
text(xx+.15,ff,1)
points(x0,f0,pch=19,col="black",cex=.8)
for (i in 2:R){
  xi[i] <- xx <- xx - dx(xx)/hx(xx)
  fi[i] <- ff <- fx(xx)
  points(xx,ff,pch=19,col="black",cex=.8)
  if (i<6) text(xx+.3/i,ff+.02*i,i)
  if (i==6) text(xx,ff+.125,i)
  if (i==7) text(xx-.01,ff+.125,i)
  if (i==8) text(xx+.05,ff+.125,i)
  arrows(xi[i-1],fi[i-1],xx,ff,angle=20,length=.15,lwd=wd)
}
dev.off()

postscript("hansen12-2a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",ylim=c(0,2.5),xlim=c(0,4),xaxt="n",bty="n",lwd=wd)
axis(side=1,seq(0,4,1),lwd=wd)
axis(side=2,lwd=wd)
points(x0,f0,pch=1,col="black",cex=1.4)
R <- 8
xi <- matrix(0,R,1)
fi <- matrix(0,R,1)
xi[1] <- xx <- .1
fi[1] <- ff <- fx(xx)
points(xx,ff,pch=19,col="black",cex=.8)
text(xx+.15,ff,1)
points(x0,f0,pch=19,col="black",cex=.8)
for (i in 2:R){
  xi[i] <- xx <- xx - dx(xx)/hx(xx)
  fi[i] <- ff <- fx(xx)
  points(xx,ff,pch=19,col="black",cex=.8)
  if (i<6) text(xx+.3/i,ff+.02*i,i)
  if (i==6) text(xx,ff+.125,i)
  if (i==7) text(xx-.01,ff+.125,i)
  if (i==8) text(xx+.05,ff+.125,i)
  arrows(xi[i-1],fi[i-1],xx,ff,angle=20,length=.15,lwd=wd)
}
dev.off()

cat("Newton Search \n")
print(cbind(xi,fi))


## Golden Section Search

pdf("hansen12-2b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",ylim=c(0,2.5),xlim=c(0,4.1),xaxt="n",bty="n",lwd=wd)
axis(side=1,seq(0,4,1),lwd=wd)
axis(side=2,lwd=wd)
points(x0,f0,pch=1,col="black",cex=1.4)
points(x0,f0,pch=19,col="black",cex=.8)
R <- 16
gi <- matrix(0,R,1)
yi <- matrix(0,R,1)
phi <- (1+sqrt(5))/2
yi[1] <- a <- 0.1
yi[2] <- b <- 4
yi[3] <- c <- b-(b-a)/phi
yi[4] <- d <- a+(b-a)/phi
gi[1] <- fa <- fx(a)
gi[2] <- fb <- fx(b)
gi[3] <- fc <- fx(c)
gi[4] <- fd <- fx(d)
hc <- fb-(fb-fa)/phi
hd <- fa+(fb-fa)/phi
lines(c(a,b),c(fa,fb),lty=2,lwd=wd)
points(a,fa,pch=19,col="black",cex=.8)
points(b,fb,pch=19,col="black",cex=.8)
points(c,hc,pch=19,col="black",cex=.8)
points(d,hd,pch=19,col="black",cex=.8)
text(.2,2.45,"a")
text(3.95,fb+.15,"b")
text(c,hc+.15,"c")
text(d,hd+.15,"d")
points(c,fc,pch=19,col="black",cex=.8)
points(d,fd,pch=19,col="black",cex=.8)
text(c,fc-.15,expression(f(c)),cex=.8)
text(d,fd-.15,expression(f(d)),cex=.8)
arrows(c,hc,c,fc,angle=20,length=.1,lwd=wd)
arrows(d,hd,d,fd,angle=20,length=.1,lwd=wd)
print(cbind(4,a,c,d,b))
e <- d-(d-a)/phi
fe <- fx(e)
he <- fd-(fd-fa)/phi
lines(c(a,d),c(fa,fd),lty=2,lwd=wd)
points(e,fe,pch=19,col="black",cex=.8)
points(e,he,pch=19,col="black",cex=.8)
text(e,he+.15,"e")
text(e,fe-.15,expression(f(e)))
arrows(e,he,e,fe,angle=20,length=.1,lwd=wd)
lines(c(e,d),c(fe,fd),lty=2,lwd=wd)
fnew <- e+(d-e)/phi
ff <- fx(fnew)
hf <- fe+(fd-fe)/phi
points(fnew,ff,pch=19,col="black",cex=.8)
points(fnew,hf,pch=19,col="black",cex=.8)
text(fnew,hf+.1,"f")
text(x0+.02,f0-.15,expression(x[0]))
lines(c(fnew,fnew),c(hf,ff),lwd=wd)
for (i in 5:R){	
if (fc<fd) {
  b <- d
  d <- c
  fd <- fc
  yi[i] <- c <- b-(b-a)/phi
  gi[i] <- fc <- fx(c)
} else {
  a <- c
  c <- d
  fc <- fd
  yi[i] <- d <- a+(b-a)/phi
  gi[i] <- fd <- fx(d)
}
print(cbind(i,a,c,d,b))
}
dev.off()

postscript("hansen12-2b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",ylim=c(0,2.5),xlim=c(0,4.1),xaxt="n",bty="n",lwd=wd)
axis(side=1,seq(0,4,1),lwd=wd)
axis(side=2,lwd=wd)
points(x0,f0,pch=1,col="black",cex=1.4)
points(x0,f0,pch=19,col="black",cex=.8)
R <- 16
gi <- matrix(0,R,1)
yi <- matrix(0,R,1)
phi <- (1+sqrt(5))/2
yi[1] <- a <- 0.1
yi[2] <- b <- 4
yi[3] <- c <- b-(b-a)/phi
yi[4] <- d <- a+(b-a)/phi
gi[1] <- fa <- fx(a)
gi[2] <- fb <- fx(b)
gi[3] <- fc <- fx(c)
gi[4] <- fd <- fx(d)
hc <- fb-(fb-fa)/phi
hd <- fa+(fb-fa)/phi
lines(c(a,b),c(fa,fb),lty=2,lwd=wd)
points(a,fa,pch=19,col="black",cex=.8)
points(b,fb,pch=19,col="black",cex=.8)
points(c,hc,pch=19,col="black",cex=.8)
points(d,hd,pch=19,col="black",cex=.8)
text(.2,2.45,"a")
text(3.95,fb+.15,"b")
text(c,hc+.15,"c")
text(d,hd+.15,"d")
points(c,fc,pch=19,col="black",cex=.8)
points(d,fd,pch=19,col="black",cex=.8)
text(c,fc-.15,expression(f(c)),cex=.8)
text(d,fd-.15,expression(f(d)),cex=.8)
arrows(c,hc,c,fc,angle=20,length=.1,lwd=wd)
arrows(d,hd,d,fd,angle=20,length=.1,lwd=wd)
print(cbind(4,a,c,d,b))
e <- d-(d-a)/phi
fe <- fx(e)
he <- fd-(fd-fa)/phi
lines(c(a,d),c(fa,fd),lty=2,lwd=wd)
points(e,fe,pch=19,col="black",cex=.8)
points(e,he,pch=19,col="black",cex=.8)
text(e,he+.15,"e")
text(e,fe-.15,expression(f(e)))
arrows(e,he,e,fe,angle=20,length=.1,lwd=wd)
lines(c(e,d),c(fe,fd),lty=2,lwd=wd)
fnew <- e+(d-e)/phi
ff <- fx(fnew)
hf <- fe+(fd-fe)/phi
points(fnew,ff,pch=19,col="black",cex=.8)
points(fnew,hf,pch=19,col="black",cex=.8)
text(fnew,hf+.1,"f")
text(x0+.02,f0-.15,expression(x[0]))
lines(c(fnew,fnew),c(hf,ff),lwd=wd)
for (i in 5:R){	
if (fc<fd) {
  b <- d
  d <- c
  fd <- fc
  yi[i] <- c <- b-(b-a)/phi
  gi[i] <- fc <- fx(c)
} else {
  a <- c
  c <- d
  fc <- fd
  yi[i] <- d <- a+(b-a)/phi
  gi[i] <- fd <- fx(d)
}
print(cbind(i,a,c,d,b))
}
dev.off()

