#####################################
### This file generates Figures 12.4 and 12.5
### Multivariate Optimization
######################################## 
### Uses data file cps09mar.txt
### Uses package spatstat
#########################################

library(spatstat)

dat <- read.table("cps09mar.txt")
experience <- dat[,1]-dat[,4]-6
hisp <- (dat[,3]==1)&(dat[,2]==1) &(experience<=15)&(experience>=10)
dat1 <- dat[hisp,]
wage <- as.matrix(dat1[,5]/(dat1[,6]*dat1[,7]))
n <- length(wage)
lwage <- log(wage)
mwage <- mean(lwage)
y_dat <- lwage - mwage

# moment estimator
mu4 <- mean(y_dat^4)
v <- var(y_dat)
v4 <- v^2
thetat <- mwage
v2t <- mu4*v/(2*mu4-3*v4)
r <- (4*mu4-6*v4)/(mu4-3*v4)

beta <- c(r,v2t)

like <- function(beta) {
  r <- beta[1]
  v <- beta[2]
  f <- (n/2)*log(pi*v*r) - n*lgamma((1+r)/2) + n*lgamma(r/2) + ((1+r)/2)*sum(log(1+(y_dat^2)/(v*r)))
return(f)
}

grad <- function(beta) {
  r <- beta[1]
  v <- beta[2]
  y2 <- y_dat^2
  gv <- n/(2*v) - ((r+1)/(2*r*(v^2)))*sum(y2/(1+y2/(r*v)))
  gr <- (n/2)*(1/r - digamma((r+1)/2) + digamma(r/2)) + (1/2)*sum(log(1+y2/(r*v))) - ((r+1)/(2*v*(r^2)))*sum(y2/(1+y2/(r*v)))
  g <- rbind(gr,gv)
return(g)
} 

hess <- function(beta) {
  r <- beta[1]
  v <- beta[2]
  y2 <- y_dat^2
  H <- matrix(0,2,2)
  X2 <- sum(y2/(1+y2/(r*v)))
  X4 <- sum((y2/(1+y2/(r*v)))^2)
  H[1,1] <- - X4*(1+1/r)/(r*(r*v)^2)/2 + X2/v/(r^3) - n/2/(r^2) - n*trigamma((r+1)/2)/4 + n*trigamma(r/2)/4
  H[2,1] <- H[1,2] <- X2/2/((r*v)^2) - X4*(1/(r^2)+1/(r^3))/2/(v^3)
  H[2,2] <- -n/(2*v*v) + X2*(1+1/r)/(v^3) - X4*(1/r+1/(r^2))/(v^4)/2
return(H)
}

newt <- function(beta) return(beta-solve(hess(beta),grad(beta)))

vs <- seq(.1,.5,.001)
nv <- length(vs)
rs <- seq(2.2,20,.2)
nr <- length(rs)
ff <- matrix(0,nr,nv)
for (i in 1:nv){
for (j in 1:nr){
  bj <- c(rs[j],vs[i])
  ff[j,i] <- like(bj)
}}
r0 <- rs[which.min(apply(ff,1,min))]
v0 <- vs[which.min(apply(t(ff),1,min))]
x0 <- c(r0,v0)
x0 <- newt(newt(newt(x0)))

wd <- 1.4

# Grid Search 
pdf("hansen12-4a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)
for (i in 1:nv){
for (j in 1:nr){
  if (((i/10)==round(i/10))*((j/2)==round(j/2))) points(rs[j],vs[i],pch=19,col="black",cex=.15)
}}
dev.off()

postscript("hansen12-4a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)
for (i in 1:nv){
for (j in 1:nr){
  if (((i/10)==round(i/10))*((j/2)==round(j/2))) points(rs[j],vs[i],pch=19,col="black",cex=.15)
}}
dev.off()

f1 <- vs[apply(ff,1,which.min)] 

# Steepest Descent
pdf("hansen12-4b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)
x1 <- c(4,.25)
x2 <- x1 - grad(x1)/2500
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(6,.18)
x2 <- x1 - grad(x1)/5000
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(8,.35)
x2 <- x1 - grad(x1)/1650
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(10,.15)
x2 <- x1 - grad(x1)/7500
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(12,.3)
x2 <- x1 - grad(x1)/2200
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(14,.2)
x2 <- x1 - grad(x1)/5000
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(16,.45)
x2 <- x1 - grad(x1)/1100
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(18,.15)
x2 <- x1 - grad(x1)/8500
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(7,.45)
x2 <- x1 - grad(x1)/1000
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(3,.4)
x2 <- x1 - grad(x1)/1100
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
dev.off()

postscript("hansen12-4b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)
x1 <- c(4,.25)
x2 <- x1 - grad(x1)/2500
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(6,.18)
x2 <- x1 - grad(x1)/5000
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(8,.35)
x2 <- x1 - grad(x1)/1650
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(10,.15)
x2 <- x1 - grad(x1)/7500
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(12,.3)
x2 <- x1 - grad(x1)/2200
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(14,.2)
x2 <- x1 - grad(x1)/5000
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(16,.45)
x2 <- x1 - grad(x1)/1100
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(18,.15)
x2 <- x1 - grad(x1)/8500
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(7,.45)
x2 <- x1 - grad(x1)/1000
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
x1 <- c(3,.4)
x2 <- x1 - grad(x1)/1100
d <- grad(x1)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lty=1,lwd=wd)
dev.off()


# Newton
pdf("hansen12-5a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1.0,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1.0)
x1 <- c(4,.25)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(6,.18)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(8,.35)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(10,.15)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(12,.3)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(14,.2)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(16,.45)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=1)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(18,.15)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(7,.45)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(3,.4)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
dev.off()

postscript("hansen12-5a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1.0,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1.0)
x1 <- c(4,.25)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(6,.18)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(8,.35)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(10,.15)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(12,.3)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(14,.2)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(16,.45)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=1)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(18,.15)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(7,.45)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
x1 <- c(3,.4)
H <- hess(x1)
g <- grad(x1)
d <- solve(H,g)
d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
x2 <- x1 - d/10
points(x1[1],x1[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
ev <- eigen(H)
L <- ev$values
if (min(L) < 0){
  V <- ev$vectors
  d <- V%*%diag(1/abs(L))%*%t(V)%*%g
  d <- d/sqrt((d[1]/17)^2+(d[2]/.4)^2)
  x2 <- x1 - d/10
  points(x1[1],x1[2],pch=19,col="black",cex=.75)
  arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=2*wd)
}
dev.off()


# Trust Region
pdf("hansen12-5b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1.0,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)

da <- 1
db <- .025
D <- diag(c(1/da^2,1/db^2))
L <- 100
delta <- 1

x1 <- c(18,.15)
points(x1[1],x1[2],pch=19,col="black",cex=.75)
g <- grad(x1)
H <- hess(x1)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x1,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
rootf <- function(x) t(g)%*%solve(H+D*x)%*%D%*%solve(H+D*x)%*%g-delta
lambda <- uniroot(rootf,c(0,L))
x2 <- x1 - solve(H + D*lambda$root,g)
points(x2[1],x2[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
dx <- x2-x1
rho <- -(like(x1)-like(x2))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x2)
H <- hess(x2)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x2,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x3 <- x2 - solve(H + D*lambda$root,g)
points(x3[1],x3[2],pch=19,col="black",cex=.75)
arrows(x2[1],x2[2],x3[1],x3[2],angle=20,length=.1,lwd=wd)
dx <- x3-x2
rho <- -(like(x2)-like(x3))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x3)
H <- hess(x3)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x3,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x4 <- x3 - solve(H + D*lambda$root,g)
points(x4[1],x4[2],pch=19,col="black",cex=.75)
arrows(x3[1],x3[2],x4[1],x4[2],angle=20,length=.1,lwd=wd)
dx <- x4-x3
rho <- -(like(x3)-like(x4))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x4)
H <- hess(x4)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x4,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x5 <- x4 - solve(H + D*lambda$root,g)
points(x5[1],x5[2],pch=19,col="black",cex=.75)
arrows(x4[1],x4[2],x5[1],x5[2],angle=20,length=.1,lwd=wd)
dx <- x5-x4
rho <- -(like(x4)-like(x5))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x5)
H <- hess(x5)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x5,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x6 <- x5 - solve(H + D*lambda$root,g)
points(x6[1],x6[2],pch=19,col="black",cex=.75)
arrows(x5[1],x5[2],x6[1],x6[2],angle=20,length=.1,lwd=wd)
dx <- x6-x5
rho <- -(like(x5)-like(x6))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x6)
H <- hess(x6)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x6,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
x7 <- x6 - solve(H,g)/8
points(x7[1],x7[2],pch=19,col="black",cex=.75)
arrows(x6[1],x6[2],x7[1],x7[2],angle=20,length=.1,lwd=wd)
dx <- x7-x6
rho <- -(like(x6)-like(x7))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x7)
H <- hess(x7)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x7,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
x8 <- x7 - solve(H,g)
arrows(x7[1],x7[2],x8[1],x8[2],angle=20,length=.1,lwd=wd)
dx <- x8-x7
rho <- -(like(x7)-like(x8))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x8)
H <- hess(x8)
x9 <- x8 - solve(H,g)

dev.off()

postscript("hansen12-5b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1.0,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)

da <- 1
db <- .025
D <- diag(c(1/da^2,1/db^2))
L <- 100
delta <- 1

x1 <- c(18,.15)
points(x1[1],x1[2],pch=19,col="black",cex=.75)
g <- grad(x1)
H <- hess(x1)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x1,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
rootf <- function(x) t(g)%*%solve(H+D*x)%*%D%*%solve(H+D*x)%*%g-delta
lambda <- uniroot(rootf,c(0,L))
x2 <- x1 - solve(H + D*lambda$root,g)
points(x2[1],x2[2],pch=19,col="black",cex=.75)
arrows(x1[1],x1[2],x2[1],x2[2],angle=20,length=.1,lwd=wd)
dx <- x2-x1
rho <- -(like(x1)-like(x2))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x2)
H <- hess(x2)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x2,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x3 <- x2 - solve(H + D*lambda$root,g)
points(x3[1],x3[2],pch=19,col="black",cex=.75)
arrows(x2[1],x2[2],x3[1],x3[2],angle=20,length=.1,lwd=wd)
dx <- x3-x2
rho <- -(like(x2)-like(x3))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x3)
H <- hess(x3)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x3,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x4 <- x3 - solve(H + D*lambda$root,g)
points(x4[1],x4[2],pch=19,col="black",cex=.75)
arrows(x3[1],x3[2],x4[1],x4[2],angle=20,length=.1,lwd=wd)
dx <- x4-x3
rho <- -(like(x3)-like(x4))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x4)
H <- hess(x4)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x4,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x5 <- x4 - solve(H + D*lambda$root,g)
points(x5[1],x5[2],pch=19,col="black",cex=.75)
arrows(x4[1],x4[2],x5[1],x5[2],angle=20,length=.1,lwd=wd)
dx <- x5-x4
rho <- -(like(x4)-like(x5))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x5)
H <- hess(x5)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x5,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
lambda <- uniroot(rootf,c(0,L))
x6 <- x5 - solve(H + D*lambda$root,g)
points(x6[1],x6[2],pch=19,col="black",cex=.75)
arrows(x5[1],x5[2],x6[1],x6[2],angle=20,length=.1,lwd=wd)
dx <- x6-x5
rho <- -(like(x5)-like(x6))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x6)
H <- hess(x6)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x6,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
x7 <- x6 - solve(H,g)/8
points(x7[1],x7[2],pch=19,col="black",cex=.75)
arrows(x6[1],x6[2],x7[1],x7[2],angle=20,length=.1,lwd=wd)
dx <- x7-x6
rho <- -(like(x6)-like(x7))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x7)
H <- hess(x7)
W1 <- ellipse(a=da*sqrt(delta),b=db*sqrt(delta),centre=x7,phi=0,npoly=1024)
plot(W1,add=TRUE,lwd=wd)
x8 <- x7 - solve(H,g)
arrows(x7[1],x7[2],x8[1],x8[2],angle=20,length=.1,lwd=wd)
dx <- x8-x7
rho <- -(like(x7)-like(x8))/(t(g)%*%dx+t(dx)%*%H%*%dx/2)
if (rho>=0.9) delta <- delta*2
if (rho<0.1) delta <- delta/2

g <- grad(x8)
H <- hess(x8)
x9 <- x8 - solve(H,g)

dev.off()