#####################################
### This file generates Figure 12.6
### Nelder-Mead
#####################################


dat <- read.table("cps09mar.txt")
experience <- dat[,1]-dat[,4]-6
hisp <- (dat[,3]==1)&(dat[,2]==1) &(experience<=15)&(experience>=10)
dat1 <- dat[hisp,]
wage <- as.matrix(dat1[,5]/(dat1[,6]*dat1[,7]))
n <- length(wage)
lwage <- log(wage)
mwage <- mean(lwage)
y_dat <- lwage - mwage

like <- function(beta) {
  r <- beta[1]
  v <- beta[2]
  f <- (n/2)*log(pi*v*r) - n*lgamma((1+r)/2) + n*lgamma(r/2) + ((1+r)/2)*sum(log(1+(y_dat^2)/(v*r)))
return(f)
}

vs <- seq(.1,.5,.001)
nv <- length(vs)
rs <- seq(2.2,20,.2)
nr <- length(rs)
ff <- matrix(0,nr,nv)
for (i in 1:nv){
for (j in 1:nr){
  bj <- c(rs[j],vs[i])
  ff[j,i] <- like(bj)
}}
r0 <- rs[which.min(apply(ff,1,min))]
v0 <- vs[which.min(apply(t(ff),1,min))]
x0 <- c(r0,v0)

wd <- 1.4

pdf("hansen12-6a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1.0)
X <- matrix(0,3,2)
f <- matrix(0,3,1)
X[,1] <- c(17,18.5,20)
X[,2] <- c(.1,.15,.1)
points(X[1,1],X[1,2],pch=19,col="black",cex=.75)
points(X[2,1],X[2,2],pch=19,col="black",cex=.75)
points(X[3,1],X[3,2],pch=19,col="black",cex=.75)
f[1] <- like(X[1,])
f[2] <- like(X[2,])
f[3] <- like(X[3,])
i <- order(f)
f <- f[i]
X <- X[i,]
text(18.5,.134,"1",cex=.8)
polygon(X,lwd=wd)

c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
xr <- xr*2 - c
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(15,.155,"2",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
xr <- xr*2 - c
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(14.5,.212,"3",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(12.8,.23,"4",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(10,.29,"5",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"6",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),.27,"7",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(11.0,mean(X[,2]),"8",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"9",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"10",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"11",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(6.9,mean(X[,2]),"12",cex=.6)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"13",cex=.6)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(5.1,.205,"14",cex=.6)
polygon(X,lwd=wd)
dev.off()

postscript("hansen12-6a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1.0)
X <- matrix(0,3,2)
f <- matrix(0,3,1)
X[,1] <- c(17,18.5,20)
X[,2] <- c(.1,.15,.1)
points(X[1,1],X[1,2],pch=19,col="black",cex=.75)
points(X[2,1],X[2,2],pch=19,col="black",cex=.75)
points(X[3,1],X[3,2],pch=19,col="black",cex=.75)
f[1] <- like(X[1,])
f[2] <- like(X[2,])
f[3] <- like(X[3,])
i <- order(f)
f <- f[i]
X <- X[i,]
text(18.5,.134,"1",cex=.8)
polygon(X,lwd=wd)

c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
xr <- xr*2 - c
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(15,.155,"2",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
xr <- xr*2 - c
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(14.5,.212,"3",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(12.8,.23,"4",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(10,.29,"5",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"6",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),.27,"7",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(11.0,mean(X[,2]),"8",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"9",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"10",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"11",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(6.9,mean(X[,2]),"12",cex=.6)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"13",cex=.6)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(5.1,.205,"14",cex=.6)
polygon(X,lwd=wd)
dev.off()


pdf("hansen12-6b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)

X <- matrix(0,3,2)
f <- matrix(0,3,1)
X[,1] <- c(3.2,20,3.2)
X[,2] <- c(.1,.1,.5)
points(X[1,1],X[1,2],pch=19,col="black",cex=.75)
points(X[2,1],X[2,2],pch=19,col="black",cex=.75)
points(X[3,1],X[3,2],pch=19,col="black",cex=.75)
f[1] <- like(X[1,])
f[2] <- like(X[2,])
f[3] <- like(X[3,])
i <- order(f)
f <- f[i]
X <- X[i,]
text(14,.15,"1",cex=1)
polygon(X,lwd=wd)

c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(5,.35,"2",cex=1)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(5,.15,"3",cex=1)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(6,.27,"4",cex=1)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(9.7,mean(X[,2]),"5",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(8.3,mean(X[,2]),"6",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(6.4,.2,"7",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),.24,"8",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"9",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"10",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"11",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"12",cex=.6)
polygon(X,lwd=wd)

dev.off()

postscript("hansen12-6b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
contour(rs,vs,ff,nlevels=45, drawlabels=FALSE,xlab="r",ylab=expression(nu),xaxs="i",yaxs="i",xaxt="n",yaxt="n",cex.lab=1,lwd=wd)	
axis(side=1,seq(2,20,2),lwd=wd)
axis(side=2,seq(.1,.7,.1),lwd=wd)
points(x0[1],x0[2],pch=19,col="black",cex=1)

X <- matrix(0,3,2)
f <- matrix(0,3,1)
X[,1] <- c(3.2,20,3.2)
X[,2] <- c(.1,.1,.5)
points(X[1,1],X[1,2],pch=19,col="black",cex=.75)
points(X[2,1],X[2,2],pch=19,col="black",cex=.75)
points(X[3,1],X[3,2],pch=19,col="black",cex=.75)
f[1] <- like(X[1,])
f[2] <- like(X[2,])
f[3] <- like(X[3,])
i <- order(f)
f <- f[i]
X <- X[i,]
text(14,.15,"1",cex=1)
polygon(X,lwd=wd)

c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(5,.35,"2",cex=1)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(5,.15,"3",cex=1)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(6,.27,"4",cex=1)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(9.7,mean(X[,2]),"5",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(8.3,mean(X[,2]),"6",cex=.8)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(6.4,.2,"7",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),.24,"8",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- (c + X[3,])/2
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"9",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"10",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"11",cex=.7)
polygon(X,lwd=wd)

i <- order(f)
f <- f[i]
X <- X[i,]
c <- colMeans(X[1:2,])
xr <- c*2 - X[3,]
X[3,] <- xr
f[3] <- like(xr)
points(xr[1],xr[2],pch=19,col="black",cex=.75)
text(mean(X[,1]),mean(X[,2]),"12",cex=.6)
polygon(X,lwd=wd)

dev.off()

