#####################################
### This file generates Figure 16.4-16.5
### Credible Sets
#####################################


x <- seq(-2,2.5,.001)
mu <- 0
lambda <- 3
alpha <- 2
beta <- 2
n2 <- 10
xbar <- 1
sigma2 <- 2
xbar2 <- (n2*xbar + lambda*mu)/(n2+lambda)
dof <- n2 - 1
dof2 <- n2 - 1 + 2*alpha
s1 <- 2*beta
s2 <- n2*sigma2+2*beta
v2 <- dof2/s2
scale2 <- 1/sqrt((n2+lambda)*v2)

b2 <- dt((x-xbar2)/scale2,dof2)/scale2
bm2 <- dt(0,dof2)/scale2
q2 <- qt(.975,dof2)
cr1 <- xbar2 - q2/sqrt((n2+lambda)*v2)
cr2 <- xbar2 + q2/sqrt((n2+lambda)*v2)
br1 <- dt((cr1-xbar2)/scale2,dof2)/scale2
br2 <- dt((cr2-xbar2)/scale2,dof2)/scale2

q <- qt(.975,dof)
cL <- xbar - q*sqrt(sigma2/dof)
cU <- xbar + q*sqrt(sigma2/dof)
br <- -br1/2

pdf("hansen16-4.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,b2,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(-.5,2.2),ylim=c(-0.07,1.1),ylab="",xlab="",yaxt="n",xaxt="n",bty="n")
points(xbar,0.01,pch=19,col="black",cex=.6)
text(0.5,.22,"Bayes",cex=.75)
text(1.27,.22,"MLE",cex=.75)
arrows(1.16,.19,1.02,.03,angle=20,length=.1)
arrows(0.63,.19,.75,.03,angle=20,length=.1)
points(xbar2,0.01,pch=19,col="black",cex=.6)
lines(c(cr1,cr2),c(br1,br2),lwd=1.5)
arrows(cr1,br1,cr1,0,angle=20,length=.1)
arrows(cr2,br2,cr2,0,angle=20,length=.1)
arrows(.35,.2,.2,br1,angle=20,length=.1)
arrows(1.36,.19,1.4,br,angle=20,length=.1)
lines(c(cL,cU),c(br,br),lwd=1.5)
arrows(cL,br,cL,0,angle=20,length=.1)
arrows(cU,br,cU,0,angle=20,length=.1)
lines(c(-1,3),c(0,0))
text(1.4,.72,expression(paste(pi,"(",theta,"|X)")),cex=.8)
dev.off()

postscript("hansen16-4.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,b2,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(-.5,2.2),ylim=c(-0.07,1.1),ylab="",xlab="",yaxt="n",xaxt="n",bty="n")
points(xbar,0.01,pch=19,col="black",cex=.6)
text(0.5,.22,"Bayes",cex=.75)
text(1.27,.22,"MLE",cex=.75)
arrows(1.16,.19,1.02,.03,angle=20,length=.1)
arrows(0.63,.19,.75,.03,angle=20,length=.1)
points(xbar2,0.01,pch=19,col="black",cex=.6)
lines(c(cr1,cr2),c(br1,br2),lwd=1.5)
arrows(cr1,br1,cr1,0,angle=20,length=.1)
arrows(cr2,br2,cr2,0,angle=20,length=.1)
arrows(.35,.2,.2,br1,angle=20,length=.1)
arrows(1.36,.19,1.4,br,angle=20,length=.1)
lines(c(cL,cU),c(br,br),lwd=1.5)
arrows(cL,br,cL,0,angle=20,length=.1)
arrows(cU,br,cU,0,angle=20,length=.1)
lines(c(-1,3),c(0,0))
text(1.4,.72,expression(paste(pi,"(",theta,"|X)")),cex=.8)
dev.off()


x <- seq(0,2,.001)
b2 <- dchisq(x*s2,dof2)*s2
v2 <- dof2/s2
vm2 <- dchisq(v2*s2,dof2)*s2

mle <- 1/sigma2
c1 = qchisq(.025,dof)/(n2*sigma2)
c2 = qchisq(.975,dof)/(n2*sigma2)
br <- -.1

credible <- function(L){
 F <- pchisq(L*s2,dof2)
 Q <- qchisq(.95+F,dof2)/s2
 f <- dchisq(L*s2,dof2)*s2 - dchisq(Q*s2,dof2)*s2
return(f)
}
LU <- qchisq(.05,dof2)/s2
cred <- uniroot(credible,c(0,LU))
L <- cred$root
U <- qchisq(.95+pchisq(L*s2,dof2),dof2)/s2
qL <- dchisq(L*s2,dof2)*s2
qU <- dchisq(U*s2,dof2)*s2

pdf("hansen16-5.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,b2,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(0,1.5),ylim=c(-.12,2.1),ylab="",xlab="",xaxt="n",yaxt="n",bty="n")
lines(c(0,2),c(0,0))
points(mle,0.01,pch=19,col="black",cex=.6)
points(v2,0.01,pch=19,col="black",cex=.6)
text(.33,.4,"MLE",cex=.75)
arrows(.38,.34,.48,.03,angle=20,length=.1)
arrows(.27,.34,.24,br,angle=20,length=.1)
text(.7,.4,"Bayes",cex=.75)
arrows(.62,.34,.55,.03,angle=20,length=.1)
arrows(.78,.36,.82,qL,angle=20,length=.1)
lines(c(c1,c2),c(br,br),lwd=1.5)
arrows(c1,br,c1,0,angle=20,length=.1)
arrows(c2,br,c2,0,angle=20,length=.1)
lines(c(L,U),c(qL,qU),lwd=1.5)
arrows(L,qL,L,0,angle=20,length=.1)
arrows(U,qU,U,0,angle=20,length=.1)
text(0.8,1.4,expression(paste(pi,"(",theta,"|X)")),cex=.8)
dev.off()

postscript("hansen16-5.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,b2,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(0,1.5),ylim=c(-.12,2.1),ylab="",xlab="",xaxt="n",yaxt="n",bty="n")
lines(c(0,2),c(0,0))
points(mle,0.01,pch=19,col="black",cex=.6)
points(v2,0.01,pch=19,col="black",cex=.6)
text(.33,.4,"MLE",cex=.75)
arrows(.38,.34,.48,.03,angle=20,length=.1)
arrows(.27,.34,.24,br,angle=20,length=.1)
text(.7,.4,"Bayes",cex=.75)
arrows(.62,.34,.55,.03,angle=20,length=.1)
arrows(.78,.36,.82,qL,angle=20,length=.1)
lines(c(c1,c2),c(br,br),lwd=1.5)
arrows(c1,br,c1,0,angle=20,length=.1)
arrows(c2,br,c2,0,angle=20,length=.1)
lines(c(L,U),c(qL,qU),lwd=1.5)
arrows(L,qL,L,0,angle=20,length=.1)
arrows(U,qU,U,0,angle=20,length=.1)
text(0.8,1.4,expression(paste(pi,"(",theta,"|X)")),cex=.8)
dev.off()
