#####################################
### This file generates Figure 17.5
### Choice of Bandwidth
#####################################
### Uses data file cps09mar.txt
#########################################
 
dat <- read.table("cps09mar.txt")
wage <- as.matrix(dat[,5]/(dat[,6]*dat[,7]))
asianfemale <- (dat[,11]==4)*(dat[,2]==1)
w <- wage[asianfemale==1]

# Bandwidths
n15 <- length(w)^(1/5)
s1 <- sd(w)
iqr <- IQR(w)
s2 <- iqr/1.34
s <- min(s1,s2)
b1 <- 1.06*s1/n15
b2 <- 0.9*s/n15
b3 <- bw.SJ(w)
cat("n^1/5")
print(n15)
cat("standard deviation")
print(s1)
cat("interquartile range")
print(iqr)
cat("min(sd,IQR/1.34)")
print(s)
cat("Gaussian Rule bandwidth")
print(b1)
cat("Rule of Thumb bandwidth")
print(b2)
cat("SJ bandwidth")
print(b3)
den1 <- density(w,bw=b1)		
den2 <- density(w,bw=b2)		
den3 <- density(w,bw=b3)		


pdf("hansen17-5.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(den1$x, den1$y, type="l",lty=1,xlab="",ylab="",xaxt="n", yaxt="n",title=NULL,xaxs="i",yaxs="i",xlim=c(0,60),ylim=c(0,.04),bty="n")
lines(den2,lty=5)
lines(den3,lty=2)
axis(side=1,seq(0,60,10),cex.axis=.75)
legend("topright",c("Gaussian Optimal", "Rule of Thumb", "Sheather-Jones"), lty=c(1,5,2),cex=.75,bty="n")	
dev.off()

postscript("hansen17-5.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(den1$x, den1$y, type="l",lty=1,xlab="",ylab="",xaxt="n", yaxt="n",title=NULL,xaxs="i",yaxs="i",xlim=c(0,60),ylim=c(0,.04),bty="n")
lines(den2,lty=5)
lines(den3,lty=2)
axis(side=1,seq(0,60,10),cex.axis=.75)
legend("topright",c("Gaussian Optimal", "Rule of Thumb", "Sheather-Jones"), lty=c(1,5,2),cex=.75,bty="n")	
dev.off()