#####################################
### This file generates Figure 3.5
### Beta, Pareto
#####################################


#####################################
### Beta
#####################################

x <- seq(0,1,.001)
b1 <- dbeta(x,2,2)
b2 <- dbeta(x,2,5)
b3 <- dbeta(x,5,1)
leg1 <- expression(paste(alpha==2,", ",beta==2))
leg2 <- expression(paste(alpha==2,", ",beta==5))
leg3 <- expression(paste(alpha==5,", ",beta==1))

wd <- 1.4

pdf("hansen3-5a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,b1,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(0,1),ylim=c(0,3.6),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,lwd=wd)
lines(x,b2,lty=5,lwd=wd)
lines(x,b3,lty=2,lwd=wd)
legend("top",legend=c(leg1,leg2,leg3),lty=c(1,5,2),y.intersp=1.3,lwd=wd,bty="n")
dev.off()

postscript("hansen3-5a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,b1,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(0,1),ylim=c(0,3.6),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,lwd=wd)
lines(x,b2,lty=5,lwd=wd)
lines(x,b3,lty=2,lwd=wd)
legend("top",legend=c(leg1,leg2,leg3),lty=c(1,5,2),y.intersp=1.3,lwd=wd,bty="n")
dev.off()


#####################################
### Lognormal
#####################################

x <- seq(0,3,by=0.001)
v = 1
f1 <- exp(-((log(x))^2)/2/v)/sqrt(2*pi)/sqrt(v)/x
v = 1/4
f2 <- exp(-((log(x))^2)/2/v)/sqrt(2*pi)/sqrt(v)/x
v = 1/16
f3 <- exp(-((log(x))^2)/2/v)/sqrt(2*pi)/sqrt(v)/x
leg1 <- expression(v==1)
leg2 <- expression(v==1/4)
leg3 <- expression(v==1/16)

pdf("hansen3-5b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f1,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(0,3),ylim=c(0,1.7),ylab="",xlab="",yaxt="n",xaxt="n",bty="n",lwd=wd)
lines(x,f2,lty=2,lwd=wd)
lines(x,f3,lty=5,lwd=wd)
axis(side=1,seq(0,3,1),lwd=wd)
legend("topright",legend=c(leg1,leg2,leg3),lty=c(1,2,5),y.intersp=1.3,lwd=wd,bty="n")
dev.off()

postscript("hansen3-5b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f1,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(0,3),ylim=c(0,1.7),ylab="",xlab="",yaxt="n",xaxt="n",bty="n",lwd=wd)
lines(x,f2,lty=2,lwd=wd)
lines(x,f3,lty=5,lwd=wd)
axis(side=1,seq(0,3,1),lwd=wd)
legend("topright",legend=c(leg1,leg2,leg3),lty=c(1,2,5),y.intersp=1.3,lwd=wd,bty="n")
dev.off()
