#####################################
### This file generates Figure 3.6
### Weibull, Gumbell
#####################################


#####################################
### Weibell
#####################################

x <- seq(0,3,by=0.001)
k1 <- 1/2
k2 <- 1
k3 <- 2
k4 <- 4
y1 <- k1*(x^(k1-1))*exp(-x^k1)
y2 <- k2*(x^(k2-1))*exp(-x^k2)
y3 <- k3*(x^(k3-1))*exp(-x^k3)
y4 <- k4*(x^(k4-1))*exp(-x^k4)
leg1 <- expression(alpha==1/2)
leg2 <- expression(alpha==1)
leg3 <- expression(alpha==2)
leg4 <- expression(alpha==4)

wd <- 1.4

pdf("hansen3-6a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,y1,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(-.1,3),ylim=c(0,2),ylab="",xlab="",yaxt="n",xaxt="n",bty="n",lwd=wd)
lines(x,y2,lty=5,lwd=wd)
lines(x,y3,lty=2,lwd=wd)
lines(x,y4,lty=4,lwd=wd)
legend("topright",legend=c(leg1,leg2,leg3,leg4),lty=c(1,5,2,4),y.intersp=1.3,lwd=wd,bty="n")
axis(side=1,seq(0,3,1),lwd=wd)
abline(v=0,lwd=wd)
dev.off()

postscript("hansen3-6a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,y1,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(-.1,3),ylim=c(0,2),ylab="",xlab="",yaxt="n",xaxt="n",bty="n",lwd=wd)
lines(x,y2,lty=5,lwd=wd)
lines(x,y3,lty=2,lwd=wd)
lines(x,y4,lty=4,lwd=wd)
legend("topright",legend=c(leg1,leg2,leg3,leg4),lty=c(1,5,2,4),y.intersp=1.3,lwd=wd,bty="n")
axis(side=1,seq(0,3,1),lwd=wd)
abline(v=0,lwd=wd)
dev.off()

#####################################
### Gumbel
#####################################

x <- seq(-3,6,by=0.01)
f <- exp(-(x+exp(-x)))

pdf("hansen3-6b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(-3,6),ylim=c(0,.4),ylab="",xlab="",yaxt="n",xaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-3,6,1),lwd=wd)
dev.off()

postscript("hansen3-6b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f,type="l",lty=1,xaxs="i",yaxs="i",xlim=c(-3,6),ylim=c(0,.4),ylab="",xlab="",yaxt="n",xaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-3,6,1),lwd=wd)
dev.off()
