#####################################
### This file generates Figure 3.7
### Mixtures of Normals
#####################################


#####################################
### Normal
#####################################

phi <- function (x,m,s) exp(-(((x-m)/s)^2)/2)/(s*sqrt(2*pi))

x <- seq(-3.5,3.5,by=0.01)

# Skewed
f1 <- phi(x,-.3,sqrt(1.2))*3/5 + phi(x,.2,sqrt(1.2)/2)/5 + phi(x,.7,sqrt(1.2)/2)/5

wd <- 1.4

pdf("hansen3-7a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x ,f1,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.45),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

postscript("hansen3-7a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x ,f1,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.45),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()


# Strongly Skewed
s = 3/sqrt(511)
sv = s*sqrt(2)
f2 <- (phi(x,-.95,s) + phi(x,-3/4,sv) + phi(x,-1/2,2*s) + phi(x,-1/4,2*sv) + phi(x,0,4*s) + phi(x,1/4,4*sv) + phi(x,1/2,8*s) + phi(x,3/4,8*sv) + phi(x,1,16*s))/9

pdf("hansen3-7b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f2,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.66),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

postscript("hansen3-7b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f2,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.66),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

# Kurtotic
f3 <- phi(x,0,10*sqrt(10/703))*7/10 + phi(x,0,sqrt(10/703))*3/10 

pdf("hansen3-7c.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f3,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,1.25),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

postscript("hansen3-7c.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f3,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,1.25),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

# Bimodal
f4 <- phi(x,-7/8,sqrt(15)/8)/2 + phi(x,7/8,sqrt(15)/8)/2 

pdf("hansen3-7d.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f4,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.42),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

postscript("hansen3-7d.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f4,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.42),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()


# Skewed Bimodal
f5 <- phi(x,-3/8,sqrt(237/320))*3/4 + phi(x,9/8,sqrt(237/320)/3)/4

pdf("hansen3-7e.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f5,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.43),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

postscript("hansen3-7e.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f5,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.43),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()


# Claw
sig1 <- sqrt(199/100)
sig2 <- sqrt(2-sig1^2)
f6 <- phi(x,0,sig1)/2 + (phi(x,-1,sig2) + phi(x,-1/2,sig2) + phi(x,0,sig2) + phi(x,1/2,sig2) + phi(x,1,sig2))/10

pdf("hansen3-7f.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,f6,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.55),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()

postscript("hansen3-7f.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,f6,type="l",lty=1,xaxs="i",yaxs="i",ylim=c(0,.55),xlim=c(-3.5,3.5),ylab="",xlab="",yaxt="n",bty="n",lwd=wd)
axis(side=1,seq(-4,4,1),lwd=wd)
dev.off()
