#####################################
### This file generates Figure 4.10 
### conditional density
#####################################
### Uses data file cps09mar.txt
#########################################

dat <- read.table("cps09mar.txt")
wage <- as.matrix(dat[,5]/(dat[,6]*dat[,7]))
ex <- dat[,1] - dat[,4] - 6

n6 <- length(wage)^(-1/6)
hw <- .9*sd(wage)*n6
he <- 1.5*sd(ex)*n6

x <- c(0,8,20)
y <- seq(0,60,.25)
N <- length(y)
f <- matrix(0,N,3)

for (i in 1:3){
  d <- dnorm((ex-x[i])/he)
  fx <- mean(d)
  for (j in 1:N) {
    fy <- mean(d*dnorm((wage-y[j])/hw))/hw
    f[j,i] <- fy/fx
  }
}

pdf("hansen4-10.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(y,f[,1],type="l",lty=1,xlim=c(-0.1,60),ylim=c(0,.055),xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n")
lines(y,f[,2])
lines(y,f[,3])
lines(c(0,0),c(0,f[1,1]))
axis(side=1,seq(-10,70,10),cex.axis=.75)
text(18,.052,"f(y|x=0)",cex=.75)
text(22,.04,"f(y|x=8)",cex=.75)
text(30,.027,"f(y|x=20)",cex=.75)
dev.off()

postscript("hansen4-10.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(y,f[,1],type="l",lty=1,xlim=c(-0.1,60),ylim=c(0,.055),xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n")
lines(y,f[,2])
lines(y,f[,3])
lines(c(0,0),c(0,f[1,1]))
axis(side=1,seq(-10,70,10),cex.axis=.75)
text(18,.052,"f(y|x=0)",cex=.75)
text(22,.04,"f(y|x=8)",cex=.75)
text(30,.027,"f(y|x=20)",cex=.75)
dev.off()
