#####################################
### This file generates Figure 4.11
### conditional expectation
#####################################
### Uses data file cps09mar.txt
#########################################

dat <- read.table("cps09mar.txt")
wage <- as.matrix(dat[,5]/(dat[,6]*dat[,7]))
ed <- dat[,4]
ex <- dat[,1] - ed - 6

n6 <- length(wage)^(-1/6)
he <- 2*sd(ex)*n6

x <- seq(0,50,1)
N <- length(x)
m <- matrix(0,N,1)

for (i in 1:N){
  d <- dnorm((ex-x[i])/he)
  m[i] <- mean(d*wage)/mean(d)
}

wd <- 1.4

pdf("hansen4-11a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,m,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",xaxt="n",ylim=c(0,55),lwd=wd)
axis(side=1,seq(0,60,10),lwd=wd)
axis(side=2,seq(0,60,10),lwd=wd)
text(40,28,"E[Y|X=x]")
dev.off()

postscript("hansen4-11a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,m,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",xaxt="n",ylim=c(0,55),lwd=wd)
axis(side=1,seq(0,60,10),lwd=wd)
axis(side=2,seq(0,60,10),lwd=wd)
text(40,28,"E[Y|X=x]")
dev.off()

ed <- ed*(ed>8) + matrix(8,length(ed),1)*(ed<=8)
y <- c(8,9,10,11,12,13,14,16,18,20)
N <- length(y)
mwage <- matrix(0,N,1)

for (i in 1:N){
 wagei <- wage[which(ed==y[i])]
 mwage[i] <- mean(wagei)
}

x <- seq(7,21,.001)
w <- .2
yy <- matrix(0,length(x),N)
for (i in 1:N){
yy[,i] <- (abs(x-y[i]) < w)*mwage[i]
}

pdf("hansen4-11b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,yy[,1],type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",xaxt="n",bty="n",ylim=c(0,55),lwd=wd)
for (i in 1:N) lines(x,yy[,i],lwd=wd)
axis(side=1,seq(6,22,2),lwd=wd)
axis(side=2,seq(0,60,10),lwd=wd)
text(13,28,"E[Y|X=x]")
dev.off()

postscript("hansen4-11b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,yy[,1],type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",xaxt="n",bty="n",ylim=c(0,55),lwd=wd)
for (i in 1:N) lines(x,yy[,i],lwd=wd)
axis(side=1,seq(6,22,2),lwd=wd)
axis(side=2,seq(0,60,10),lwd=wd)
text(13,28,"E[Y|X=x]")
dev.off()
