#####################################
### This file generates Figure 4.12
### conditional variance
#####################################
### Uses data file cps09mar.txt
#########################################

dat <- read.table("cps09mar.txt")
wage <- as.matrix(dat[,5]/(dat[,6]*dat[,7]))
ed <- dat[,4]
ex <- dat[,1] - ed - 6

n6 <- length(wage)^(-1/6)
he <- 4*sd(ex)*n6

x <- seq(0,50,1)
N <- length(x)
v <- matrix(0,N,1)
wage2 <- wage^2
for (i in 1:N){
  d <- dnorm((ex-x[i])/he)
  m1 <- mean(d*wage)/mean(d)
  m2 <- mean(d*wage2)/mean(d)
  v[i] <- m2 -(m1^2)
}

wd <- 1.4

pdf("hansen4-12a.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,v,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n",ylim=c(0,1800),lwd=wd)
axis(side=1,seq(0,50,10),lwd=wd)
axis(side=2,seq(0,2000,400),lwd=wd)
text(30,700,"var[Y|X=x]")
dev.off()

postscript("hansen4-12a.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,v,type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",bty="n",yaxt="n",xaxt="n",ylim=c(0,1800),lwd=wd)
axis(side=1,seq(0,50,10),lwd=wd)
axis(side=2,seq(0,2000,400),lwd=wd)
text(30,700,"var[Y|X=x]")
dev.off()

ed <- ed*(ed>8) + matrix(8,length(ed),1)*(ed<=8)
y <- c(8,9,10,11,12,13,14,16,18,20)
N <- length(y)
mwage <- matrix(0,N,1)
vwage <- matrix(0,N,1)

for (i in 1:N){
 wagei <- wage[which(ed==y[i])]
 mwage[i] <- mean(wagei)
 vwage[i] <- var(wagei)
}

x <- seq(7,21,.001)
w <- .2
yy <- matrix(0,length(x),N)
for (i in 1:N){
yy[,i] <- (abs(x-y[i]) < w)*vwage[i]
}

pdf("hansen4-12b.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,yy[,1],type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",yaxt="n",xaxt="n",bty="n",ylim=c(0,1800),lwd=wd)
for (i in 1:N) lines(x,yy[,i],lwd=wd)
axis(side=1,seq(6,22,2),lwd=wd)
axis(side=2,seq(0,2000,400),lwd=wd)
text(14,800,"var[Y|X=x]")
dev.off()

postscript("hansen4-12b.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,yy[,1],type="l",lty=1,xaxs="i",yaxs="i",ylab="",xlab="",yaxt="n",xaxt="n",bty="n",ylim=c(0,1800),lwd=wd)
for (i in 1:N) lines(x,yy[,i],lwd=wd)
axis(side=1,seq(6,22,2),lwd=wd)
axis(side=2,seq(0,2000,400),lwd=wd)
text(14,800,"var[Y|X=x]")
dev.off()
