#####################################
### This file generates Figures 4.8 and 4.9
### Conditional Distribution and Density Function
#####################################
### Uses data file cps09mar.txt
#########################################

dat <- read.table("cps09mar.txt")
wage <- as.matrix(dat[,5]/(dat[,6]*dat[,7]))
ed <- dat[,4]

wage1 <- wage[which(ed==12)]
wage2 <- wage[which(ed==16)]
wage3 <- wage[which(ed==18)]
wage4 <- wage[which(ed==20)]

x <- c(seq(0,9,1),seq(10,40,2.5),seq(45,80,5))
n <- length(x)
F1 <- matrix(1,n,1)
F2 <- matrix(1,n,1)
F3 <- matrix(1,n,1)
F4 <- matrix(1,n,1)
for (i in 1:n){
  F1[i] <- mean(wage1 <= x[i])
  F2[i] <- mean(wage2 <= x[i])
  F3[i] <- mean(wage3 <= x[i])
  F4[i] <- mean(wage4 <= x[i])
}

leg1 <- 

pdf("hansen4-8.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(x,F1, type="l",lty=1,xlab="",ylab="",xaxt="n", yaxt="n",ylim=c(0,1),title=NULL,xaxs="i",yaxs="i",bty="n")
lines(x,F2)
lines(x,F3)
lines(x,F4)
axis(side=1,seq(0,100,10),cex.axis=.75)
axis(side=2,seq(0,1,0.2),cex.axis=.75)
text(20,.9,"F(y|x=12)",cex=.75)
text(32,.8,"F(y|x=16)",cex=.75)
text(47,.73,"F(y|x=18)",cex=.75)
text(55,.6,"F(y|x=20)",cex=.75)
dev.off()

postscript("hansen4-8.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(x,F1, type="l",lty=1,xlab="",ylab="",xaxt="n", yaxt="n",ylim=c(0,1),title=NULL,xaxs="i",yaxs="i",bty="n")
lines(x,F2)
lines(x,F3)
lines(x,F4)
axis(side=1,seq(0,100,10),cex.axis=.75)
axis(side=2,seq(0,1,0.2),cex.axis=.75)
text(20,.9,"F(y|x=12)",cex=.75)
text(32,.8,"F(y|x=16)",cex=.75)
text(47,.73,"F(y|x=18)",cex=.75)
text(55,.6,"F(y|x=20)",cex=.75)
dev.off()


f1 <- density(wage1,from=0,to=80,adjust=2.5)		
f2 <- density(wage2,from=0,to=80,adjust=2)		
f3 <- density(wage3,from=0,to=80,adjust=2)		
f4 <- density(wage4,from=0,to=80,adjust=1)		

pdf("hansen4-9.pdf",family="Helvetica",colormodel='cmyk',width=4.5,height=4.5)
plot(f1$x,f1$y,type="l",lty=1,xlim=c(-.1,80),ylim=c(0,.056),xlab="",ylab="",xaxt="n",yaxt="n",title=NULL,xaxs="i",yaxs="i",bty="n")
lines(f2$x,f2$y)
lines(f3$x,f3$y)
lines(f4$x,f4$y)
axis(side=1,seq(-10,100,10),cex.axis=.75)
lines(c(0,0),c(0,f1$y[1]))
text(25,.05,"f(y|x=12)",cex=.75)
text(30,.033,"f(y|x=16)",cex=.75)
text(40,.025,"f(y|x=18)",cex=.75)
text(70,.01,"f(y|x=20)",cex=.75)
dev.off()

postscript("hansen4-9.eps",paper="special",width=4.5,height=4.5,horizontal=FALSE,onefile=FALSE,family="Helvetica",colormodel='cmyk')
plot(f1$x,f1$y,type="l",lty=1,xlim=c(-.1,80),ylim=c(0,.056),xlab="",ylab="",xaxt="n",yaxt="n",title=NULL,xaxs="i",yaxs="i",bty="n")
lines(f2$x,f2$y)
lines(f3$x,f3$y)
lines(f4$x,f4$y)
axis(side=1,seq(-10,100,10),cex.axis=.75)
lines(c(0,0),c(0,f1$y[1]))
text(25,.05,"f(y|x=12)",cex=.75)
text(30,.033,"f(y|x=16)",cex=.75)
text(40,.025,"f(y|x=18)",cex=.75)
text(70,.01,"f(y|x=20)",cex=.75)
dev.off()
